ad_page_contract {
    Load all catalog files.

    @author Peter Marklund (peter@collaboraid.biz)
    @creation-date 2002-10-07
    @cvs-id $Id: reload-cache.tcl,v 1.1.24.1 2015/09/10 08:21:30 gustafn Exp $
}

lang::message::cache

ad_returnredirect "index"

# Local variables:
#    mode: tcl
#    tcl-indent-level: 4
#    indent-tabs-mode: nil
# End:
